pub(crate) fn get_imginfo(
storage: &Storage,
deployment_id: &str,
) -> Result<ImgConfigManifest>Expand description
Retrieves the OCI manifest and config for a deployment from the composefs repository.
The manifest digest is read from the deployment’s .origin file,
then OciImage::open() retrieves manifest+config from the composefs repo
where composefs-rs stores them as splitstreams during pull.
Falls back to reading legacy .imginfo files for backwards compatibility
with deployments created before the manifest digest was stored in .origin.